@@ -2,7 +2,7 @@
 #define SXEVAL_SXEVAL_HPP
 
 #include "sxeval/AOperation.hpp"
-#include "sxeval/AOperand.hpp"
+#include "sxeval/IOperand.hpp"
 #include "sxeval/operations/OperationsFactory.hpp"
 #include "sxeval/Value.hpp"
 #include "sxeval/Variable.hpp"
@@ -108,14 +108,14 @@ public:
     { build(expression, resolveVariable, resolveEncapsulated); }
 
     /**
-     * @brief Evaluate the expression tree.
+     * @brief Compute the result of the expression tree.
      *
-     * @return The result of the evaluation.
+     * @return The result of the computation.
      * @throws std::runtime_error if no operations have been registered or if
      * the evaluation fails.
      * @note build() must have been called before calling this method.
      */
-    T evaluate() const;
+    T execute() const;
 
     /**
      * @brief Compute the result of an expression without building its tree.
@@ -137,7 +137,7 @@ public:
      * the result of the expression. It is useful for quick/unique evaluations
      * without the overhead of building a tree.
      */
-    T compute(const std::string& expression,
+    T interpret(const std::string& expression,
         const resolveVariable_t<T>& resolveVariable = resolveVariable_t<T>(),
         const resolveEncapsulated_t<T>& resolveEncapsulated
         = resolveEncapsulated_t<T>()) const;
@@ -161,16 +161,16 @@ public:
      * @note This method does not build the expression tree, it only computes
      * the result of the expression. It is useful for quick/unique evaluations
      * without the overhead of building a tree.
-     * @note This is an overload of the compute() method that allows
+     * @note This is an overload of the interpret() method that allows
      * specifying the resolveEncapsulated function first, which can be useful if
      * the resolveVariable function is not needed.
      */
-    inline T compute(const std::string& expression,
+    inline T interpret(const std::string& expression,
         const resolveEncapsulated_t<T>& resolveEncapsulated
         = resolveEncapsulated_t<T>(),
         const resolveVariable_t<T>& resolveVariable = resolveVariable_t<T>())
         const
-    { return compute(expression, resolveVariable, resolveEncapsulated); }
+    { return interpret(expression, resolveVariable, resolveEncapsulated); }
 
     /**
      * @brief Convert the expression tree to a string representation.
@@ -181,7 +181,7 @@ public:
 
 private:
     struct _Node {
-        std::unique_ptr<AInstruction<T>> instruct;
+        std::unique_ptr<IInstruction<T>> instruct;
         _Node* parent;
         std::vector<_Node> subnodes;
 
@@ -197,7 +197,7 @@ private:
     static void _fillParents(_Node& parent);
     static void _buildTreeStr(std::ostream& oss, const _Node& node, size_t depth
         );
-    T _compute(const std::string& exp, size_t* idx,
+    T _interpret(const std::string& exp, size_t* idx,
         const resolveVariable_t<T>& resolveVariable,
         const resolveEncapsulated_t<T>& resolveEncapsulated) const;
 
@@ -245,7 +245,7 @@ void sxeval::SXEval<T>::build(const std::string& expression,
 }
 
 template <typename T>
-T sxeval::SXEval<T>::evaluate() const {
+T sxeval::SXEval<T>::execute() const {
     if (_operations.size() == 0) {
         throw std::runtime_error("No operations found");
     }
@@ -259,16 +259,16 @@ T sxeval::SXEval<T>::evaluate() const {
 }
 
 template <typename T>
-T sxeval::SXEval<T>::compute(const std::string& expression,
+T sxeval::SXEval<T>::interpret(const std::string& expression,
     const resolveVariable_t<T>& resolveVariable,
     const resolveEncapsulated_t<T>& resolveEncapsulated) const
 {
     size_t idx = 0;
-    return _compute(expression, &idx, resolveVariable, resolveEncapsulated);
+    return _interpret(expression, &idx, resolveVariable, resolveEncapsulated);
 }
 
 template <typename T>
-T sxeval::SXEval<T>::_compute(const std::string& exp, size_t* idx,
+T sxeval::SXEval<T>::_interpret(const std::string& exp, size_t* idx,
     const resolveVariable_t<T>& resolveVariable,
     const resolveEncapsulated_t<T>& resolveEncapsulated) const
 {
@@ -278,13 +278,13 @@ T sxeval::SXEval<T>::_compute(const std::string& exp, size_t* idx,
         /* ### OPERATION ### */
         (*idx)++;
         const auto symbol = _getNextSymbol(exp, idx);
-        std::vector<std::unique_ptr<AInstruction<T>>> args;
-        std::vector<AInstruction<T>*> pargs;
+        std::vector<std::unique_ptr<IInstruction<T>>> args;
+        std::vector<IInstruction<T>*> pargs;
         _skipChars(exp, idx);
         while (exp[*idx] != ')') {
-            const auto val = _compute(exp, idx, resolveVariable,
+            const auto val = _interpret(exp, idx, resolveVariable,
                 resolveEncapsulated);
-            args.push_back(std::make_unique<Value<T>>(val));
+            args.push_back(std::unique_ptr<IInstruction<T>>(new Value<T>(val)));
             pargs.push_back(args.back().get());
             _skipChars(exp, idx);
         }
@@ -403,7 +403,7 @@ typename sxeval::SXEval<T>::_Node sxeval::SXEval<T>::_build(size_t* idx,
             _skipChars(_expression, idx);
         }
         (*idx)++;
-        std::vector<AInstruction<T>*> args;
+        std::vector<IInstruction<T>*> args;
         for (auto& subnode : node.subnodes) {
             args.push_back(subnode.instruct.get());
         }
@@ -418,7 +418,8 @@ typename sxeval::SXEval<T>::_Node sxeval::SXEval<T>::_build(size_t* idx,
         _Node node;
         try {
             T val = StringToType<T>(symbol);
-            node = {std::make_unique<Value<T>>(val), nullptr, {}};
+            node = { std::unique_ptr<IInstruction<T>>(new Value<T>(val)),
+                nullptr, {} };
             #ifdef SXEVAL_DEBUG
             {
                 node.id = nodeCount++;
@@ -434,8 +435,10 @@ typename sxeval::SXEval<T>::_Node sxeval::SXEval<T>::_build(size_t* idx,
             /* as this is not castable, this may be a variable */
             try {
                 T& var = resolveVariable(symbol);
-                node = {std::make_unique<Variable<T>>(var, symbol), nullptr, {}
-                    };
+                node = {
+                    std::unique_ptr<IInstruction<T>>(
+                        new Variable<T>(var, symbol)
+                    ), nullptr, {} };
                 #ifdef SXEVAL_DEBUG
                 {
                     node.id = nodeCount++;
@@ -452,8 +455,10 @@ typename sxeval::SXEval<T>::_Node sxeval::SXEval<T>::_build(size_t* idx,
                  * encapsulated variable */
                 try {
                     auto get = resolveEncapsulated(symbol);
-                    node = {std::make_unique<EncapsulatedVariable<T>>(get,
-                        symbol), nullptr, {}};
+                    node = {
+                        std::unique_ptr<IInstruction<T>>(
+                            new EncapsulatedVariable<T>(get, symbol)
+                        ), nullptr, {} };
                     _encapsulated.push_back(
                         dynamic_cast<EncapsulatedVariable<T>*>(
                         node.instruct.get()));
@@ -472,9 +477,13 @@ typename sxeval::SXEval<T>::_Node sxeval::SXEval<T>::_build(size_t* idx,
                     /* last chance, check if it is a true/false keyword
                      */
                     if (symbol == "true") {
-                        node = {std::make_unique<Value<T>>(1), nullptr, {}};
+                        node = {
+                            std::unique_ptr<IInstruction<T>>(new Value<T>(1)),
+                            nullptr, {} };
                     } else if (symbol == "false") {
-                        node = {std::make_unique<Value<T>>(0), nullptr, {}};
+                        node = {
+                            std::unique_ptr<IInstruction<T>>(new Value<T>(0)),
+                            nullptr, {} };
                     } else {
                         throw std::runtime_error("Unknown variable: " + symbol);
                     }
