@@ -17,7 +17,7 @@ public:
     static constexpr const int ARITY_MIN = 2;
     static constexpr const int ARITY_MAX = 2;
 
-    inline ArcTangent2(const std::vector<AInstruction<T>*>& args) :
+    inline ArcTangent2(const std::vector<IInstruction<T>*>& args) :
         AOperation<T>(args) {}
 
     void execute() override;
@@ -32,10 +32,13 @@ public:
 
 /* IMPLEMENTATIONS */
 
+template <typename T>
+constexpr const char* sxeval::operations::ArcTangent2<T>::KEY;
+
 template <typename T>
 void sxeval::operations::ArcTangent2<T>::execute() {
-    this->getResult() = static_cast<T>(std::atan2(this->getArgs().front()->getResult(),
-        this->getArgs().back()->getResult()));
+    this->_result = static_cast<T>(std::atan2(this->_args.front().get(),
+        this->_args.back().get()));
 }
 
 #endif /* SXEVAL_OPERATIONS_ARCTANGENT2_HPP */
