@@ -16,7 +16,7 @@ public:
     static constexpr const int ARITY_MIN = 2;
     static constexpr const int ARITY_MAX = AOperation<T>::UNLIMITED_ARITY;
 
-    inline Average(const std::vector<AInstruction<T>*>& args) :
+    inline Average(const std::vector<IInstruction<T>*>& args) :
         AOperation<T>(args) {}
 
     void execute() override;
@@ -31,13 +31,16 @@ public:
 
 /* IMPLEMENTATIONS */
 
+template <typename T>
+constexpr const char* sxeval::operations::Average<T>::KEY;
+
 template <typename T>
 void sxeval::operations::Average<T>::execute() {
-    this->getResult() = static_cast<T>(0);
-    for (const auto& arg : this->getArgs()) {
-        this->getResult() += arg->getResult();
+    this->_result = static_cast<T>(0);
+    for (const auto& arg : this->_args) {
+        this->_result += arg.get();
     }
-    this->getResult() /= static_cast<T>(this->getArgs().size());
+    this->_result /= static_cast<T>(this->_args.size());
 }
 
 #endif /* SXEVAL_OPERATIONS_AVERAGE_HPP */
