@@ -16,7 +16,7 @@ public:
     static constexpr const int ARITY_MIN = 1;
     static constexpr const int ARITY_MAX = 1;
 
-    inline DegreesToRadians(const std::vector<AInstruction<T>*>& args) :
+    inline DegreesToRadians(const std::vector<IInstruction<T>*>& args) :
         AOperation<T>(args) {}
 
     void execute() override;
@@ -31,9 +31,13 @@ public:
 
 /* IMPLEMENTATIONS */
 
+template <typename T>
+constexpr const char* sxeval::operations::DegreesToRadians<T>::KEY;
+
 template <typename T>
 void sxeval::operations::DegreesToRadians<T>::execute() {
-    this->getResult() = this->getArgs()[0]->getResult() * static_cast<T>(SXEVAL_PI / 180.0);
+    this->_result = this->_args.front().get() *
+        static_cast<T>(SXEVAL_PI / 180.0);
 }
 
 #endif /* SXEVAL_OPERATIONS_DEGREESTORADIANS_HPP */
