@@ -16,7 +16,7 @@ public:
     static constexpr const int ARITY_MIN = 1;
     static constexpr const int ARITY_MAX = 1;
 
-    inline GradiansToDegrees(const std::vector<AInstruction<T>*>& args) :
+    inline GradiansToDegrees(const std::vector<IInstruction<T>*>& args) :
         AOperation<T>(args) {}
 
     void execute() override;
@@ -31,9 +31,12 @@ public:
 
 /* IMPLEMENTATIONS */
 
+template <typename T>
+constexpr const char* sxeval::operations::GradiansToDegrees<T>::KEY;
+
 template <typename T>
 void sxeval::operations::GradiansToDegrees<T>::execute() {
-    this->getResult() = this->getArgs()[0]->getResult() * static_cast<T>(0.9);
+    this->_result = this->_args.front().get() * static_cast<T>(0.9);
 }
 
 #endif /* SXEVAL_OPERATIONS_GRADIANSTODEGREES_HPP */
