@@ -17,7 +17,7 @@ public:
     static constexpr const int ARITY_MIN = 2;
     static constexpr const int ARITY_MAX = AOperation<T>::UNLIMITED_ARITY;
 
-    inline GreaterOrEqual(const std::vector<AInstruction<T>*>& args) :
+    inline GreaterOrEqual(const std::vector<IInstruction<T>*>& args) :
         AOperation<T>(args) {}
 
     void execute() override;
@@ -32,21 +32,24 @@ public:
 
 /* IMPLEMENTATIONS */
 
+template <typename T>
+constexpr const char* sxeval::operations::GreaterOrEqual<T>::KEY;
+
 template <typename T>
 void sxeval::operations::GreaterOrEqual<T>::execute() {
-    this->getResult() = static_cast<T>(1);
+    this->_result = static_cast<T>(1);
     size_t i = 0;
     bool verif = true;
-    while (verif && (i + 1) < this->getArgs().size()) {
-        verif = sxeval::GreaterOrEqual(this->getArgs()[i]->getResult(),
-            this->getArgs()[i + 1]->getResult());
+    while (verif && (i + 1) < this->_args.size()) {
+        verif = sxeval::GreaterOrEqual(this->_args[i].get(),
+            this->_args[i + 1].get());
         ++i;
     }
     if (verif) {
-        this->getResult() = static_cast<T>(1);
+        this->_result = static_cast<T>(1);
     }
     else {
-        this->getResult() = static_cast<T>(0);
+        this->_result = static_cast<T>(0);
     }
 }
 
