@@ -16,7 +16,7 @@ public:
     static constexpr const int ARITY_MIN = 2;
     static constexpr const int ARITY_MAX = 2;
 
-    inline LogarithmB(const std::vector<AInstruction<T>*>& args) :
+    inline LogarithmB(const std::vector<IInstruction<T>*>& args) :
         AOperation<T>(args) {}
 
     void execute() override;
@@ -31,10 +31,13 @@ public:
 
 /* IMPLEMENTATIONS */
 
+template <typename T>
+constexpr const char* sxeval::operations::LogarithmB<T>::KEY;
+
 template <typename T>
 void sxeval::operations::LogarithmB<T>::execute() {
-    this->getResult() = static_cast<T>(std::log(this->getArgs().front()->getResult()) /
-        std::log(this->getArgs().back()->getResult()));
+    this->_result = static_cast<T>(std::log(this->_args.front().get()) /
+        std::log(this->_args.back().get()));
 }
 
 #endif /* SXEVAL_OPERATIONS_LOGARITHMB_HPP */
