@@ -17,7 +17,7 @@ public:
     static constexpr const int ARITY_MIN = 1;
     static constexpr const int ARITY_MAX = 1;
 
-    inline LogicalNot(const std::vector<AInstruction<T>*>& args) :
+    inline LogicalNot(const std::vector<IInstruction<T>*>& args) :
         AOperation<T>(args) {}
 
     void execute() override;
@@ -32,10 +32,13 @@ public:
 
 /* IMPLEMENTATIONS */
 
+template <typename T>
+constexpr const char* sxeval::operations::LogicalNot<T>::KEY;
+
 template <typename T>
 void sxeval::operations::LogicalNot<T>::execute() {
-    this->getResult() = static_cast<T>(sxeval::LogicalNot(
-        this->getArgs().front()->getResult()));
+    this->_result = static_cast<T>(
+        sxeval::LogicalNot(this->_args.front().get()));
 }
 
 #endif /* SXEVAL_OPERATIONS_LOGICALNOT_HPP */
