@@ -17,7 +17,7 @@ public:
     static constexpr const int ARITY_MIN = 2;
     static constexpr const int ARITY_MAX = AOperation<T>::UNLIMITED_ARITY;
 
-    inline Maximum(const std::vector<AInstruction<T>*>& args) :
+    inline Maximum(const std::vector<IInstruction<T>*>& args) :
         AOperation<T>(args) {}
 
     void execute() override;
@@ -32,12 +32,15 @@ public:
 
 /* IMPLEMENTATIONS */
 
+template <typename T>
+constexpr const char* sxeval::operations::Maximum<T>::KEY;
+
 template <typename T>
 void sxeval::operations::Maximum<T>::execute() {
-    this->getResult() = this->getArgs().front()->getResult();
-    for (size_t i = 1; i < this->getArgs().size(); ++i) {
-        this->getResult() = static_cast<T>(std::max(this->getResult(),
-            this->getArgs()[i]->getResult()));
+    this->_result = this->_args.front();
+    for (size_t i = 1; i < this->_args.size(); ++i) {
+        this->_result = static_cast<T>(std::max(this->_result,
+            this->_args[i].get()));
     }
 }
 
