@@ -16,7 +16,7 @@ public:
     static constexpr const int ARITY_MIN = 2;
     static constexpr const int ARITY_MAX = AOperation<T>::UNLIMITED_ARITY;
 
-    inline Multiplication(const std::vector<AInstruction<T>*>& args) :
+    inline Multiplication(const std::vector<IInstruction<T>*>& args) :
         AOperation<T>(args) {}
 
     void execute() override;
@@ -31,11 +31,14 @@ public:
 
 /* IMPLEMENTATIONS */
 
+template <typename T>
+constexpr const char* sxeval::operations::Multiplication<T>::KEY;
+
 template <typename T>
 void sxeval::operations::Multiplication<T>::execute() {
-    this->getResult() = this->getArgs().front()->getResult();
-    for (size_t i = 1; i < this->getArgs().size(); ++i) {
-        this->getResult() *= this->getArgs()[i]->getResult();
+    this->_result = this->_args.front();
+    for (size_t i = 1; i < this->_args.size(); ++i) {
+        this->_result *= this->_args[i].get();
     }
 }
 
