@@ -17,7 +17,7 @@ public:
     static constexpr const int ARITY_MIN = 2;
     static constexpr const int ARITY_MAX = AOperation<T>::UNLIMITED_ARITY;
 
-    inline NotEqual(const std::vector<AInstruction<T>*>& args) :
+    inline NotEqual(const std::vector<IInstruction<T>*>& args) :
         AOperation<T>(args) {}
 
     void execute() override;
@@ -32,25 +32,24 @@ public:
 
 /* IMPLEMENTATIONS */
 
+template <typename T>
+constexpr const char* sxeval::operations::NotEqual<T>::KEY;
+
 template <typename T>
 void sxeval::operations::NotEqual<T>::execute() {
-    this->getResult() = static_cast<T>(1);
-    size_t i = 1, j;
+    this->_result = static_cast<T>(1);
+    size_t i = 0;
     bool verif = true;
-    while (verif && i < this->getArgs().size()) {
-        j = 0;
-        while (verif && j < i) {
-            verif = sxeval::NotEqual(this->getArgs()[j]->getResult(),
-                this->getArgs()[i]->getResult());
-            ++j;
-        }
+    while (verif && (i + 1) < this->_args.size()) {
+        verif = sxeval::NotEqual(this->_args[i].get(),
+            this->_args[i + 1].get());
         ++i;
     }
     if (verif) {
-        this->getResult() = static_cast<T>(1);
+        this->_result = static_cast<T>(1);
     }
     else {
-        this->getResult() = static_cast<T>(0);
+        this->_result = static_cast<T>(0);
     }
 }
 
