@@ -25,8 +25,8 @@
 #include "sxeval/operations/AbsoluteValue.hpp"
 #include "sxeval/operations/Average.hpp"
 #include "sxeval/operations/Ceiling.hpp"
-#include "sxeval/operations/Clamp.hpp"
 #include "sxeval/operations/Expm1.hpp"
+#include "sxeval/operations/Exp.hpp"
 #include "sxeval/operations/Floor.hpp"
 #include "sxeval/operations/Hypotenuse.hpp"
 #include "sxeval/operations/NaturalLogarithm.hpp"
@@ -89,10 +89,13 @@ public:
      * @brief Register an operation.
      *
      * @tparam OP The operation to register. The operation must inherit from
-     * sxeval::AOperation<T>.
+     * sxeval::AOperation<T> and provide the static members KEY, ARITY_MIN and
+     * ARITY_MAX.
      */
     template <typename OP>
-    void add();
+    typename std::enable_if<std::is_base_of<sxeval::AOperation<T>, OP>::value>
+        ::type
+    add();
 
     /**
      * @brief Instantiate an operation from its key and arguments.
@@ -104,7 +107,7 @@ public:
      * arguments is not valid for the operation.
      */
     std::unique_ptr<AOperation<T>> create(const std::string& key,
-        const std::vector<AInstruction<T>*> args);
+        const std::vector<IInstruction<T>*> args);
 
     /**
      * @brief Compute the result of an operation from its key and arguments.
@@ -115,13 +118,13 @@ public:
      * @throws std::invalid_argument if the key is unknown or if the number of
      * arguments is not valid for the operation.
      */
-    T compute(const std::string& key, const std::vector<AInstruction<T>*> args)
+    T compute(const std::string& key, const std::vector<IInstruction<T>*> args)
         const;
 
 private:
     std::unordered_map<std::string,
         const std::function<std::unique_ptr<AOperation<T>>(
-        const std::vector<AInstruction<T>*>&)>> _operations;
+        const std::vector<IInstruction<T>*>&)>> _operations;
 
 };
 
@@ -132,7 +135,6 @@ private:
 /* IMPLEMENTATIONS */
 
 template <typename T>
-
 sxeval::operations::OperationsFactory<T>::OperationsFactory() {
     add<Addition<T>>();
     add<Subtraction<T>>();
@@ -156,8 +158,8 @@ sxeval::operations::OperationsFactory<T>::OperationsFactory() {
     add<AbsoluteValue<T>>();
     add<Average<T>>();
     add<Ceiling<T>>();
-    add<Clamp<T>>();
     add<Expm1<T>>();
+    add<Exp<T>>();
     add<Floor<T>>();
     add<Hypotenuse<T>>();
     add<NaturalLogarithm<T>>();
@@ -192,16 +194,14 @@ sxeval::operations::OperationsFactory<T>::OperationsFactory() {
 
 template <typename T>
 template <typename OP>
-void sxeval::operations::OperationsFactory<T>::add() {
-    if constexpr (!(std::is_base_of<AOperation<T>, OP>::value)) {
-        throw std::invalid_argument("OP must be derived from AOperation");
-    }
+typename std::enable_if<std::is_base_of<sxeval::AOperation<T>, OP>::value>::type
+sxeval::operations::OperationsFactory<T>::add() {
     if (_operations.find(OP::KEY) != _operations.end()) {
         _operations.erase(OP::KEY);
     }
     const std::function<std::unique_ptr<AOperation<T>>(
-        const std::vector<AInstruction<T>*>&)> f =
-        [](const std::vector<AInstruction<T>*>& args) {
+        const std::vector<IInstruction<T>*>&)> f =
+        [](const std::vector<IInstruction<T>*>& args) {
             const auto nargs = static_cast<int>(args.size());
             if (nargs < OP::ARITY_MIN) {
                 std::ostringstream oss;
@@ -217,7 +217,7 @@ void sxeval::operations::OperationsFactory<T>::add() {
                     << OP::ARITY_MAX << " arguments";
                 throw std::invalid_argument(oss.str());
             }
-            return std::make_unique<OP>(args);
+            return std::unique_ptr<AOperation<T>>(new OP(args));
         };
     _operations.insert(std::make_pair(OP::KEY, f));
 }
@@ -225,7 +225,7 @@ void sxeval::operations::OperationsFactory<T>::add() {
 template <typename T>
 std::unique_ptr<sxeval::AOperation<T>>
 sxeval::operations::OperationsFactory<T>::create(
-    const std::string& key, const std::vector<sxeval::AInstruction<T>*> args)
+    const std::string& key, const std::vector<sxeval::IInstruction<T>*> args)
 {
     const auto it = _operations.find(key);
     if (it == _operations.end()) {
@@ -236,9 +236,8 @@ sxeval::operations::OperationsFactory<T>::create(
 
 template <typename T>
 T sxeval::operations::OperationsFactory<T>::compute(
-    const std::string& key, const std::vector<sxeval::AInstruction<T>*> args)
-    const
-{
+    const std::string& key, const std::vector<sxeval::IInstruction<T>*> args
+) const {
     const auto it = _operations.find(key);
     if (it == _operations.end()) {
         throw std::invalid_argument("Unknown operation key: " + key);
