@@ -17,7 +17,7 @@ public:
     static constexpr const int ARITY_MIN = 1;
     static constexpr const int ARITY_MAX = 1;
 
-    inline SquareRoot(const std::vector<AInstruction<T>*>& args) :
+    inline SquareRoot(const std::vector<IInstruction<T>*>& args) :
         AOperation<T>(args) {}
 
     void execute() override;
@@ -32,9 +32,12 @@ public:
 
 /* IMPLEMENTATIONS */
 
+template <typename T>
+constexpr const char* sxeval::operations::SquareRoot<T>::KEY;
+
 template <typename T>
 void sxeval::operations::SquareRoot<T>::execute() {
-    this->getResult() = static_cast<T>(std::sqrt(this->getArgs().front()->getResult()));
+    this->_result = static_cast<T>(std::sqrt(this->_args.front().get()));
 }
 
 #endif /* SXEVAL_OPERATIONS_SQUAREROOT_HPP */
