@@ -5,6 +5,7 @@
 #include <cmath>
 #include <stdexcept>
 #include <cstdio>
+#include <limits>
 
 #define SXEVAL_PI 3.14159265358979323846
 
@@ -43,15 +44,22 @@ inline bool Greater(const T& a, const T& b) {
  * @return True if a is equal to b, false otherwise.
  */
 template<typename T>
-inline bool Equal(const T& a, const T& b) {
-    if constexpr (std::is_integral_v<T>) {
+inline typename std::enable_if<std::is_integral<T>::value, bool>::type
+Equal(const T& a, const T& b) {
         return a == b;
-    } else if constexpr (std::is_floating_point_v<T>) {
-        return std::abs(a - b) <= std::numeric_limits<T>::epsilon();
-    } else {
-        static_assert(std::is_integral_v<T> || std::is_floating_point_v<T>,
-            "Unsupported type for equal");
-    }
+}
+
+/**
+ * @brief Check if a is equal to b.
+ * @tparam T The type of the values.
+ * @param a The first value.
+ * @param b The second value.
+ * @return True if a is equal to b, false otherwise.
+ */
+template<typename T>
+inline typename std::enable_if<std::is_floating_point<T>::value, bool>::type
+Equal(const T& a, const T& b) {
+    return std::abs(a - b) <= std::numeric_limits<T>::epsilon();
 }
 
 /**
@@ -63,7 +71,7 @@ inline bool Equal(const T& a, const T& b) {
  */
 template<typename T>
 inline bool NotEqual(const T& a, const T& b) {
-    return !Equal(a, b);
+    return !Equal<T>(a, b);
 }
 
 /**
@@ -75,7 +83,7 @@ inline bool NotEqual(const T& a, const T& b) {
  */
 template<typename T>
 inline bool GreaterOrEqual(const T& a, const T& b) {
-    return Greater(a, b) || Equal(a, b);
+    return Greater<T>(a, b) || Equal<T>(a, b);
 }
 
 /**
@@ -87,7 +95,7 @@ inline bool GreaterOrEqual(const T& a, const T& b) {
  */
 template<typename T>
 inline bool Less(const T& a, const T& b) {
-    return !GreaterOrEqual(a, b);
+    return !GreaterOrEqual<T>(a, b);
 }
 
 /**
@@ -99,7 +107,7 @@ inline bool Less(const T& a, const T& b) {
  */
 template<typename T>
 inline bool LessOrEqual(const T& a, const T& b) {
-    return Less(a, b) || Equal(a, b);
+    return Less<T>(a, b) || Equal<T>(a, b);
 }
 
 /**
@@ -111,15 +119,23 @@ inline bool LessOrEqual(const T& a, const T& b) {
  * the machine epsilon.
  */
 template<typename T>
-inline bool TypeToBool(const T& val) {
-    if constexpr (std::is_integral_v<T>) {
-        return val != 0;
-    } else if constexpr (std::is_floating_point_v<T>) {
-        return std::abs(val) > std::numeric_limits<T>::epsilon();
-    } else {
-        static_assert(std::is_integral_v<T> || std::is_floating_point_v<T>,
-            "Unsupported type for TypeToBool");
-    }
+inline typename std::enable_if<std::is_integral<T>::value, bool>::type
+TypeToBool(const T& val) {
+    return val != 0;
+}
+
+/**
+ * @brief Convert a type T to a boolean value.
+ * @tparam T The type to convert.
+ * @param val The value to convert.
+ * @return True if the value is non-zero, false otherwise.
+ * @note For floating point types, it checks if the absolute value is greater than
+ * the machine epsilon.
+ */
+template<typename T>
+inline typename std::enable_if<std::is_floating_point<T>::value, bool>::type
+TypeToBool(const T& val) {
+    return std::abs(val) > std::numeric_limits<T>::epsilon();
 }
 
 /**
@@ -131,7 +147,7 @@ inline bool TypeToBool(const T& val) {
  */
 template<typename T>
 inline bool LogicalAnd(const T& a, const T& b) {
-    return TypeToBool(a) && TypeToBool(b);
+    return TypeToBool<T>(a) && TypeToBool<T>(b);
 }
 
 /**
@@ -143,7 +159,7 @@ inline bool LogicalAnd(const T& a, const T& b) {
  */
 template<typename T>
 inline bool LogicalOr(const T& a, const T& b) {
-    return TypeToBool(a) || TypeToBool(b);
+    return TypeToBool<T>(a) || TypeToBool<T>(b);
 }
 
 /**
@@ -154,7 +170,7 @@ inline bool LogicalOr(const T& a, const T& b) {
  */
 template<typename T>
 inline bool LogicalNot(const T& a) {
-    return !TypeToBool(a);
+    return !TypeToBool<T>(a);
 }
 
 /**
@@ -166,7 +182,7 @@ inline bool LogicalNot(const T& a) {
  */
 template<typename T>
 inline bool LogicalXor(const T& a, const T& b) {
-    return TypeToBool(a) != TypeToBool(b);
+    return TypeToBool<T>(a) != TypeToBool<T>(b);
 }
 
 /**
@@ -178,7 +194,7 @@ inline bool LogicalXor(const T& a, const T& b) {
  */
 template<typename T>
 inline bool LogicalNand(const T& a, const T& b) {
-    return !LogicalAnd(a, b);
+    return !LogicalAnd<T>(a, b);
 }
 
 /**
@@ -190,7 +206,7 @@ inline bool LogicalNand(const T& a, const T& b) {
  */
 template<typename T>
 inline bool LogicalNor(const T& a, const T& b) {
-    return !LogicalOr(a, b);
+    return !LogicalOr<T>(a, b);
 }
 
 /**
@@ -202,7 +218,7 @@ inline bool LogicalNor(const T& a, const T& b) {
  */
 template<typename T>
 inline bool LogicalXnor(const T& a, const T& b) {
-    return !LogicalXor(a, b);
+    return !LogicalXor<T>(a, b);
 }
 
 /**
@@ -214,15 +230,23 @@ inline bool LogicalXnor(const T& a, const T& b) {
  * @throws std::invalid_argument if b is zero.
  */
 template<typename T>
-inline T Modulo(const T& a, const T& b) {
-    if constexpr (std::is_integral_v<T>) {
-        return a % b;
-    } else if constexpr (std::is_floating_point_v<T>) {
-        return std::fmod(a, b);
-    } else {
-        static_assert(std::is_integral_v<T> || std::is_floating_point_v<T>,
-            "Unsupported type for modulo");
-    }
+inline typename std::enable_if<std::is_integral<T>::value, T>::type
+Modulo(const T& a, const T& b) {
+    return a % b;
+}
+
+/**
+ * @brief Perform a modulo operation on types T.
+ * @tparam T The type of the values.
+ * @param a The first value.
+ * @param b The second value.
+ * @return The result of the modulo operation.
+ * @throws std::invalid_argument if b is zero.
+ */
+template<typename T>
+inline typename std::enable_if<std::is_floating_point<T>::value, T>::type
+Modulo(const T& a, const T& b) {
+    return std::fmod(a, b);
 }
 
 /**
@@ -234,17 +258,39 @@ inline T Modulo(const T& a, const T& b) {
  * it uses std::abs, and for floating point types, it uses std::fabs.
  */
 template<typename T>
-inline T Absolute(const T& a) {
-    if constexpr (std::is_unsigned_v<T>) {
-        return a;
-    } else if constexpr (std::is_integral_v<T>) {
-        return std::abs(a);
-    } else if constexpr (std::is_floating_point_v<T>) {
-        return std::fabs(a);
-    } else {
-        static_assert(std::is_integral_v<T> || std::is_floating_point_v<T>,
-            "Unsupported type for absolute");
-    }
+inline typename std::enable_if<std::is_unsigned<T>::value, T>::type
+Absolute(const T& a) {
+    return a;
+}
+
+/**
+ * @brief Perform an absolute value operation on types T.
+ * @tparam T The type of the value.
+ * @param a The value to get the absolute value of.
+ * @return The absolute value of a.
+ * @note For unsigned types, it returns the value itself. For integral types,
+ * it uses std::abs, and for floating point types, it uses std::fabs.
+ */
+template<typename T>
+inline typename std::enable_if<
+    std::is_integral<T>::value && !std::is_unsigned<T>::value, T>::type
+Absolute(const T& a) {
+    return std::abs(a);
+}
+
+/**
+ * @brief Perform an absolute value operation on types T.
+ * @tparam T The type of the value.
+ * @param a The value to get the absolute value of.
+ * @return The absolute value of a.
+ * @note For unsigned types, it returns the value itself. For integral types,
+ * it uses std::abs, and for floating point types, it uses std::fabs.
+ */
+template<typename T>
+inline typename std::enable_if<
+    std::is_floating_point<T>::value  && !std::is_unsigned<T>::value, T>::type
+Absolute(const T& a) {
+    return std::fabs(a);
 }
 
 } /* namespace sxeval */
